==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ko.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "요청이 실패했습니다. 네트워크 연결을 사용할 수 없습니다.",
    "Request unauthorized. Are you logged in?" : "요청이 인증되지 않았습니다. 로그인되어 있습니까?",
    "Request forbidden. Are you an administrator?" : "요청이 금지됨. 관리자 권한을 갖고 있습니까?",
    "Token expired or app not enabled! Reload the page!" : "토큰이 만료되었거나 앱이 활성화되어 있지 않습니다. 페이지를 새로 고치십시오!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "내부 서버 오류! 자세한 내용은 data/nextcloud.log 파일을 확인하십시오!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "요청이 실패했습니다. Nextcloud가 현재 관리 모드입니다!",
    "News feeds" : "뉴스 피드",
    "Unread articles" : "읽지 않은 글",
    "News" : "뉴스",
    "News folders" : "뉴스 폴더",
    "News articles" : "뉴스 기사",
    "Shared with me" : "나와 공유됨",
    "An RSS/Atom feed reader" : "RSS/Atom 피드 리더",
    "Download" : "다운로드",
    "Close" : "닫기",
    "Web address" : "웹 주소",
    "No folder" : "폴더 없음",
    "Folder name" : "폴더 이름",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Feed exists already!" : "피드가 이미 존재합니다!",
    "New folder" : "새 폴더",
    "Folder exists already!" : "폴더가 이미 존재합니다!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP 기본 인증 정보는 암호화되지 않은 상태로 저장됩니다! 서버나 데이터베이스에 접근한 모든 사용자들이 접근할 수 있습니다!",
    "Credentials" : "인증 정보",
    "Subscribe" : "구독",
    "Last job execution ran {relativeTime}. Something seems wrong." : "마지막 작업이 {relativeTime}에 실행되었습니다. 무언가 잘못된 것 같습니다.",
    "Last job ran {relativeTime}." : "마지막 작업이 {relativeTime}에 실행되었음",
    "Maximum read count per feed" : "피드당 최대 읽은 글 개수",
    "Maximum redirects" : "최대 넘겨주기 수",
    "Feed fetcher timeout" : "피드 가져오기 시간 제한",
    "Explore Service URL" : "탐색 서비스 URL",
    "Update interval" : "갱신 주기",
    "Successfully updated news configuration" : "뉴스 설정을 성공적으로 갱신함",
    "Unable to update news config" : "뉴스 설정을 갱신할 수 없음",
    "Use system cron for updates" : "시스템 cron으로 업데이트",
    "Disable this if you use a custom updater." : "사용자 지정 업데이터를 사용할 경우 이 옵션을 비활성화하십시오.",
    "Delete unread articles automatically" : "읽지 않은 글 자동으로 삭제",
    "Enable this if you also want to delete unread articles." : "읽지 않은 글을 자동으로 삭제하고자 할 경우 이 옵션을 활성화하십시오.",
    "No article selected" : "선택한 글 없음",
    "Please select an article from the list..." : "목록에서 글을 선택하십시오...",
    "Move" : "이동",
    "User Name" : "사용자 이름",
    "Share" : "공유",
    "Share with" : "다음과 공유",
    "Share with {num} users" : "{num}명의 사용자와 공유",
    "Mark read" : "읽은 상태로 표시",
    "All articles" : "모든 글",
    "Starred" : "별표",
    "Explore" : "탐색",
    "Settings" : "설정",
    "Keyboard shortcuts" : "키보드 단축키",
    "Disable mark read through scrolling" : "스크롤 시 읽은 상태로 표시 비활성화",
    "Show all articles" : "모든 글 보기",
    "Reverse ordering (oldest on top)" : "순서 뒤집기(오래된 항목 먼저)",
    "Default" : "디폴트",
    "Vertical" : "세로",
    "Horizontal" : "가로",
    "Rename Folder" : "폴더 이름 바꾸기",
    "Are you sure you want to delete?" : "삭제하시겠습니까?",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Rename Feed" : "비드 이름 바꾸기",
    "Unpin from top" : "목록에서 고정 해제",
    "Pin to top" : "목록에 고정",
    "Newest first" : "새 항목 먼저",
    "Oldest first" : "오래된 항목 먼저",
    "Default order" : "기본 순서",
    "Enable full text" : "전문 사용",
    "Disable full text" : "전문 사용 안 함",
    "Unread updated" : "업데이트된 항목 읽지 않음으로 표시",
    "Ignore updated" : "업데이트된 항목 무시",
    "Share within Instance" : "인스턴스 내에서 공유",
    "Toggle star article" : "글 별표 전환",
    "Mark unread" : "읽지 않음 상태로 표시",
    "Close details" : "자세한 정보 숨기기",
    "by" : "작성:",
    "from" : "원본 사이트:",
    "shared by" : "다음 사용자가 공유함:",
    "Play audio" : "오디오 재생",
    "Download audio" : "오디오 다운로드",
    "Download video" : "동영상 다운로드",
    "Open website" : "웹 사이트 열기",
    "Keep article unread" : "읽지 않은 상태로 유지",
    "Toggle keep current article unread" : "현재 글 읽지 않은 상태로 유지 전환",
    "Remove keep article unread" : "읽지 않은 상태로 유지하지 않음",
    "{num} seconds" : "{num}초 전",
    "{num} minutes ago" : "{num}분 전",
    "{num} hours ago" : "{num}시간 전",
    "{num} days ago" : "{num}일 전",
    "{num} months ago" : "{num}개월 전",
    "{num} years ago" : "{num}년 전",
    "Title" : "제목",
    "Keyboard shortcut" : "키보드 단축키",
    "Action" : "동작",
    "Jump to next article" : "다음 글로 이동",
    "Jump to previous article" : "이전 글로 이동",
    "right" : "오른쪽",
    "left" : "왼쪽",
    "Star article and jump to next one" : "글에 별표를 붙이고 다음 항목으로 이동",
    "Open article in new tab" : "새 탭으로 글 열기",
    "Refresh" : "새로 고침",
    "Load next feed" : "다음 피드 불러오기",
    "Load previous feed" : "이전 피드 불러오기",
    "Load previous folder" : "이전 폴더 불러오기",
    "Load next folder" : "다음 폴더 불러오기",
    "Scroll to active navigation entry" : "활성 탐색 항목으로 스크롤",
    "Shift" : "Shift",
    "All Articles" : "모든 글",
    "No feeds found to add" : "추가할 피드를 없음",
    "Subscribe to" : "다음을 구독",
    "Unread Articles" : "읽지 않은 글",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax 및 웹 cron 모드가 감지되었습니다! 피드를 업데이트하지 않습니다!",
    "How to set up the operating system cron" : "운영 체제 cron 설정 방법",
    "Install and set up a faster parallel updater that uses the News app's update API" : "뉴스 앱의 업데이트 API를 사용하는 빠른 병렬 업데이터 설치 및 설정",
    "No articles available" : "글 없음",
    "No unread articles available" : "읽지 않은 글 없음",
    "Star article" : "글에 별표 붙이기",
    "Unstar article" : "글에서 별표 떼기",
    "Share with users" : "사용자와 공유",
    "No users found" : "사용자 없음",
    "Error while searching for users" : "사용자를 검색하는 중 오류 발생",
    "Share on social media" : "소셜 미디어에 공유",
    "I wanted you to see this article" : "이 글을 읽고 싶었습니다",
    "Check out this article" : "이 글 확인하기",
    "Description" : "설명",
    "Toggle expand article in compact view" : "작은 보기에서 글 확장 전환",
    "Mark current article's feed/folder read" : "현재 글이 속한 피드/폴더를 읽은 것으로 표시",
    "Folder" : "폴더",
    "Go back" : "뒤로 가기",
    "New Folder" : "새 폴더",
    "Create" : "만들기",
    "Update failed more than 50 times" : "업데이트가 50번 이상 실패함",
    "Deleted feed" : "삭제된 피드",
    "Undo delete feed" : "피드 삭제 취소",
    "Menu" : "메뉴",
    "Open feed URL" : "피드 URL 열기",
    "Dismiss" : "닫기",
    "Collapse" : "접기",
    "Deleted folder" : "삭제된 폴더",
    "Undo delete folder" : "폴더 삭제 실행 취소",
    "Compact view" : "축소된 보기",
    "Expand articles on key navigation" : "키 탐색 시 글 확장",
    "Subscriptions (OPML)" : "구독(OPML)",
    "Import" : "가져오기",
    "Export" : "내보내기",
    "Error when importing: File does not contain valid OPML" : "가져오는 중 오류 발생: 파일에 올바른 OPML이 없음",
    "Error when importing: OPML is does neither contain feeds nor folders" : "가져오기 오류: OPML 파일에 피드나 폴더가 없음",
    "Unread/Starred Articles" : "읽지 않은/별표한 글",
    "Error when importing: file does not contain valid JSON" : "가져오기 오류: 파일이 올바른 JSON을 포함하지 않음",
    "Help" : "도움말",
    "Documentation" : "문서",
    "Report a bug" : "버그 보고"
},
"nplurals=1; plural=0;");

==> nextcloud-app-news-1%3A27.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ko.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "뉴스 피드",
    "Unread articles" : "읽지 않은 글",
    "News" : "뉴스",
    "News folders" : "뉴스 폴더",
    "News articles" : "뉴스 기사",
    "Shared with me" : "나와 공유됨",
    "An RSS/Atom feed reader" : "RSS/Atom 피드 리더",
    "Download" : "다운로드",
    "Close" : "닫기",
    "Web address" : "웹 주소",
    "No folder" : "폴더 없음",
    "Folder name" : "폴더 이름",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Feed exists already!" : "피드가 이미 존재합니다!",
    "New folder" : "새 폴더",
    "Folder exists already!" : "폴더가 이미 존재합니다!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP 기본 인증 정보는 암호화되지 않은 상태로 저장됩니다! 서버나 데이터베이스에 접근한 모든 사용자들이 접근할 수 있습니다!",
    "Credentials" : "인증 정보",
    "Subscribe" : "구독",
    "Successfully updated news configuration" : "뉴스 설정을 성공적으로 갱신함",
    "Unable to update news config" : "뉴스 설정을 갱신할 수 없음",
    "Last job ran {relativeTime}." : "마지막 작업이 {relativeTime}에 실행되었음",
    "Maximum read count per feed" : "피드당 최대 읽은 글 개수",
    "Maximum redirects" : "최대 넘겨주기 수",
    "Feed fetcher timeout" : "피드 가져오기 시간 제한",
    "Explore Service URL" : "탐색 서비스 URL",
    "Update interval" : "갱신 주기",
    "Use system cron for updates" : "시스템 cron으로 업데이트",
    "Disable this if you use a custom updater." : "사용자 지정 업데이터를 사용할 경우 이 옵션을 비활성화하십시오.",
    "Delete unread articles automatically" : "읽지 않은 글 자동으로 삭제",
    "Enable this if you also want to delete unread articles." : "읽지 않은 글을 자동으로 삭제하고자 할 경우 이 옵션을 활성화하십시오.",
    "No article selected" : "선택한 글 없음",
    "Show all articles" : "모든 글 보기",
    "Move" : "이동",
    "User Name" : "사용자 이름",
    "Share" : "공유",
    "Share with" : "다음과 공유",
    "Share with {num} users" : "{num}명의 사용자와 공유",
    "Default" : "디폴트",
    "Vertical" : "세로",
    "Horizontal" : "가로",
    "Rename Folder" : "폴더 이름 바꾸기",
    "Are you sure you want to delete?" : "삭제하시겠습니까?",
    "Mark read" : "읽은 상태로 표시",
    "All articles" : "모든 글",
    "Starred" : "별표",
    "Explore" : "탐색",
    "Settings" : "설정",
    "Documentation" : "문서",
    "Keyboard shortcuts" : "키보드 단축키",
    "Disable mark read through scrolling" : "스크롤 시 읽은 상태로 표시 비활성화",
    "Reverse ordering (oldest on top)" : "순서 뒤집기(오래된 항목 먼저)",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Rename Feed" : "비드 이름 바꾸기",
    "Unpin from top" : "목록에서 고정 해제",
    "Pin to top" : "목록에 고정",
    "Newest first" : "새 항목 먼저",
    "Oldest first" : "오래된 항목 먼저",
    "Default order" : "기본 순서",
    "Enable full text" : "전문 사용",
    "Disable full text" : "전문 사용 안 함",
    "Share within Instance" : "인스턴스 내에서 공유",
    "Toggle star article" : "글 별표 전환",
    "Mark unread" : "읽지 않음 상태로 표시",
    "Close details" : "자세한 정보 숨기기",
    "shared by" : "다음 사용자가 공유함:",
    "by" : "작성:",
    "Play audio" : "오디오 재생",
    "Download audio" : "오디오 다운로드",
    "Download video" : "동영상 다운로드",
    "Open website" : "웹 사이트 열기",
    "Keep article unread" : "읽지 않은 상태로 유지",
    "Toggle keep current article unread" : "현재 글 읽지 않은 상태로 유지 전환",
    "Remove keep article unread" : "읽지 않은 상태로 유지하지 않음",
    "Please wait" : "기다려 주세요.",
    "Title" : "제목",
    "Folder" : "폴더",
    "Keyboard shortcut" : "키보드 단축키",
    "Action" : "동작",
    "Jump to next article" : "다음 글로 이동",
    "Jump to previous article" : "이전 글로 이동",
    "right" : "오른쪽",
    "left" : "왼쪽",
    "Star article and jump to next one" : "글에 별표를 붙이고 다음 항목으로 이동",
    "Open article in new tab" : "새 탭으로 글 열기",
    "Refresh" : "새로 고침",
    "Load next feed" : "다음 피드 불러오기",
    "Load previous feed" : "이전 피드 불러오기",
    "Load previous folder" : "이전 폴더 불러오기",
    "Load next folder" : "다음 폴더 불러오기",
    "Scroll to active navigation entry" : "활성 탐색 항목으로 스크롤",
    "Shift" : "Shift",
    "All Articles" : "모든 글",
    "No feeds found to add" : "추가할 피드를 없음",
    "Subscribe to" : "다음을 구독",
    "Unread Articles" : "읽지 않은 글",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax 및 웹 cron 모드가 감지되었습니다! 피드를 업데이트하지 않습니다!",
    "How to set up the operating system cron" : "운영 체제 cron 설정 방법",
    "Install and set up a faster parallel updater that uses the News app's update API" : "뉴스 앱의 업데이트 API를 사용하는 빠른 병렬 업데이터 설치 및 설정"
},
"nplurals=1; plural=0;");
